Skip to contents

A generic function to list tables, temporary tables, and views in a database connection. This provides an enhanced view over DBI::dbListTables with categorization.

Usage

dbList(conn, ...)

Arguments

conn

A DBI database connection

...

Additional arguments passed to methods

Value

Method implementations may return different formats, typically a categorized list