S3 method for writing dbMatrix objects to a pins board while maintaining connection state and metadata consistent with the connections package.
Usage
# S3 method for class 'dbMatrix'
write_pin_conn(x, board, name, ...)Arguments
- x
A
dbMatrix::dbMatrixobject (dbSparseMatrix or dbDenseMatrix)- board
A pins
pins::board_folderobject- name
Name for the pin (required)
- ...
Additional arguments passed to
pins::pin_write()